@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/calendar/Attic/change_class.php,v 1.1.2.1 2007/12/17 13:30:59 kerrnel22 Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/calendar/Attic/change_class.php,v 1.1.2.2 2008/02/21 22:36:56 lphuberdeau Exp $
 //
 // Copyright (c)2002-2003
 // Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
@@ -16,7 +16,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 /** change_class Encompases functions that alter calendar data in the
  * database.  Extends the CalendarLib class.
  */
-class delete_class.php extends CalendarLib {
+class delete_class extends CalendarLib {
 
 	// Constructor for the change_class library.
 	function delete_class() {
@@ -30,4 +30,3 @@ class delete_class.php extends CalendarLib {
 }
 
 ?>
-
