@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/lib/calendar/Attic/display_class.php,v 1.1.2.1 2007/12/17 13:30:59 kerrnel22 Exp $
+// $Header: /cvsroot/tikiwiki/tiki/lib/calendar/Attic/display_class.php,v 1.1.2.2 2008/02/21 22:36:56 lphuberdeau Exp $
 //
 // Copyright (c)2002-2003
 // Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
@@ -16,7 +16,7 @@ if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
 /** display_class Encompases display functions that incorporate HTML in 
  * modules.  Extends the CalendarLib class.
  */
-class display_class.php extends CalendarLib {
+class display_class extends CalendarLib {
 
 	// Constructor for the display_class library.
 	function display_class() {
