@@ -1,6 +1,6 @@
 <?php
 /** \file
- * $Header: /cvsroot/tikiwiki/tiki/lib/categories/categlib.php,v 1.48.2.46 2006/09/18 17:26:32 sylvieg Exp $
+ * $Header: /cvsroot/tikiwiki/tiki/lib/categories/categlib.php,v 1.48.2.55 2007/06/12 17:43:16 nkoth Exp $
  *
  * \brief Categories support class
  *
@@ -23,29 +23,27 @@ class CategLib extends TikiLib {
 		$this->db = $db;
 	}
 
-	function list_categs() {
+	function list_categs($categId=0) {
 		global $cachelib;
 		if (!$cachelib->isCached("allcategs")) {
-			$query = "select * from `tiki_categories`";
-			$result = $this->query($query,array());
-			$ret = array();
-			while ($res = $result->fetchRow()) {
-				$catpath = $this->get_category_path($res["categId"]);
-				$tepath = array();	
-				foreach ($catpath as $cat) {
-					$tepath[] = $cat['name'];
-				}
-				$categpath = implode("::",$tepath);
-				$res["categpath"] = $categpath;
-				$res["tepath"] = $tepath;
-				$ret["$categpath"] = $res;
-			}
-			ksort($ret);
-			$back = array_values($ret);
-			$cachelib->cacheItem("allcategs",serialize($back));
-			return $back;
+			$back = $this->build_cache();
 		} else {
-			return unserialize($cachelib->getCached("allcategs"));
+			$back = unserialize($cachelib->getCached('allcategs'));
+		}
+		if ($categId > 0) {
+			$path = '';
+			$back2 = array();
+			foreach ($back as $cat) {
+				if ($cat['categId'] == $categId)
+					$path = $cat['categpath'].'::';
+				else if ($path != '' && strpos($cat['categpath'], $path) === 0) {
+					$cat['categpath'] = substr($cat['categpath'] , strlen($path));
+					$back2[] = $cat;
+				}
+			}
+			return $back2;
+		} else {
+			return $back;
 		}
 	}
 	
@@ -68,18 +66,19 @@ class CategLib extends TikiLib {
 		$ret = array();
 
 		while ($res = $result->fetchRow()) {
-			if (in_array($res["categId"], $cats)) {
+			if (!empty($cats) && in_array($res["categId"], $cats)) {
 				$res["incat"] = 'y';
 			} else {
 				$res["incat"] = 'n';
 			}
       
-      $catpath = $this->get_category_path($res["categId"]);
+			$catpath = $this->get_category_path($res["categId"]);
 			$tepath = array();	
 			foreach ($catpath as $cat) {
 				$tepath[] = $cat['name'];
 			}
 			$categpath = implode("::",$tepath);
+			$categpathforsort = implode("!!",$tepath); // needed to prevent cat::subcat to be sorted after cat2::subcat 
 			$res["categpath"] = $categpath;
 			$res["tepath"] = $tepath;
 			$res["deep"] = count($tepath);
@@ -89,16 +88,32 @@ class CategLib extends TikiLib {
 			} else {
 				$res['has_perm'] = 'n';
 			}
-			$ret["$categpath"] = $res;
+			$ret["$categpathforsort"] = $res;
 		}
+
 		ksort($ret);
 		
 		$retval = array();
-    $retval["data"] = array_values($ret);
+		$retval["data"] = array_values($ret);
 		$retval["cant"] = $cant;
 		return $retval;
 	}
-	
+
+	function get_category_path_string($categId) {
+		global $cachelib;
+		if (!$cachelib->isCached('allcategs')) {
+			$categs = $this->build_cache();
+		} else {
+			$categs = unserialize($cachelib->getCached('allcategs'));
+		}
+		foreach ($categs as $cat) {
+			if ($cat['categId'] == $categId) {
+				return $cat['categpath'];
+			}
+		}
+		return '';
+	}
+
 	function get_category_path($categId) {
 		$info = $this->get_category($categId);
 		$i=999999;
@@ -273,6 +288,7 @@ class CategLib extends TikiLib {
 	}
 
 	function list_category_objects($categId, $offset, $maxRecords, $sort_mode='pageName_asc', $type='', $find='', $deep=false, $and=false) {
+		global $userlib;
 	    
 	    // Build the condition to restrict which categories objects must be in to be returned.
 	    $join = '';
@@ -348,13 +364,16 @@ class CategLib extends TikiLib {
 		}
 
 		$allowField = preg_replace("/OR $/",") ",$allowField);
+		if (!$userlib->user_has_permission($user, 'tiki_p_admin')) { // do not filter on group if admin
 		$allowField .= " AND u.`groupName` IN (''";
 		
 		foreach ($groupList as $grp) {
 		    $bindAllow[] = $grp;
 		    $allowField .= ",?";
 		}
-		$where .= ")) OR (($allowField )))";
+			$where .= ')';
+		}
+		$where .= ") OR (($allowField )))";
 
 		$bindVars = array_merge($bindWhere, $bindAllow);
 
@@ -394,7 +413,8 @@ class CategLib extends TikiLib {
 
 	// get the parent categories of an object
 	function get_object_categories($type, $objId) {
-
+		if (!$objId)
+			return null;
 		$query = "select `categId` from `tiki_category_objects` tco, `tiki_categorized_objects` tto
     where tco.`catObjectId`=tto.`catObjectId` and `type`=? and `objId`=?";
 		//settype($objId,"string"); //objId is defined as varchar
@@ -698,7 +718,7 @@ class CategLib extends TikiLib {
 
 	// FUNCTIONS TO CATEGORIZE SPECIFIC OBJECTS END ////
 	function get_child_categories($categId) {
-		global $cachelib;
+	  global $cachelib, $language, $feature_multilingual;
 		if (!$categId) $categId = "0"; // avoid wrong cache
 		if (!$cachelib->isCached("childcategs$categId")) {
 			$ret = array();
@@ -716,6 +736,11 @@ class CategLib extends TikiLib {
 		} else {
 			$ret = unserialize($cachelib->getCached("childcategs$categId"));
 		}
+		if ($feature_multilingual == 'y' && $language != 'en') {
+			foreach ($ret as $key=>$res) {
+				$ret[$key]['name'] = tra($res['name']);
+			}
+		}
 		return $ret;
 	}
 
@@ -734,24 +759,43 @@ class CategLib extends TikiLib {
 		return $this->get_all_categories_ext();
 	}
 
+	/* build the cache with the categpath and the count */
+	function build_cache() {
+		global $cachelib;
+		$ret = array();
+		$query = "select * from `tiki_categories` order by `name`";
+		$result = $this->query($query,array());
+		while ($res = $result->fetchRow()) {
+			$id = $res["categId"];
+			$catpath = $this->get_category_path($id);
+			$tepath = array();
+			foreach ($catpath as $cat) {
+				$tepath[] = $cat['name'];
+			}
+			$categpath = implode("::",$tepath);
+			$categpathforsort = implode("!!",$tepath); // needed to prevent cat::subcat to be sorted after cat2::subcat
+			$res["categpath"] = $categpath;
+			$res["tepath"] = $tepath;
+			$query = "select count(*) from `tiki_categories` where `parentId`=?";
+			$res["children"] = $this->getOne($query,array($id));
+			$query = "select count(*) from `tiki_category_objects` where `categId`=?";
+			$res["objects"] = $this->getOne($query,array($id));
+			$ret[$categpathforsort] = $res;
+		}
+		ksort($ret);
+		$ret = array_values($ret);
+		$cachelib->cacheItem("allcategs",serialize($ret));
+		return $ret;
+	}
+
 	// Same as get_all_categories + it also get info about count of objects
 	function get_all_categories_ext() {
 		global $cachelib;
 		if (!$cachelib->isCached("allcategs")) {
-			$ret = array();
-			$query = "select * from `tiki_categories` order by `name`";
-			$result = $this->query($query,array());
-			while ($res = $result->fetchRow()) {
-				$id = $res["categId"];
-				$query = "select count(*) from `tiki_categories` where `parentId`=?";
-				$res["children"] = $this->getOne($query,array($id));
-				$query = "select count(*) from `tiki_category_objects` where `categId`=?";
-				$res["objects"] = $this->getOne($query,array($id));
-				$ret[] = $res;
-			}
-			$cachelib->cacheItem("allcategs",serialize($ret));
+			$ret = $this->build_cache();
 		} else {
 			$ret = unserialize($cachelib->getCached("allcategs"));
+
 		}
 		return $ret;
 	}
@@ -1065,8 +1109,8 @@ class CategLib extends TikiLib {
 	return $forbidden;
     }
 	function approve_submission($subId, $articleId) {
-		$query = "update `tiki_categorized_objects` set `type`= ?, `objId`= ?, `href`=? where `objId` = ?";
-		$this->query($query, array('article', (int)$articleId, "tiki-read_article.php?articleId=$articleId", (int)$subId));
+		$query = "update `tiki_categorized_objects` set `type`= ?, `objId`= ?, `href`=? where `objId` = ? and `type`= ?";
+		$this->query($query, array('article', (int)$articleId, "tiki-read_article.php?articleId=$articleId", (int)$subId, 'submission') );
 	}
 	/* build the portion of list join if filter by category
 	 */
@@ -1081,7 +1125,10 @@ class CategLib extends TikiLib {
 		else
 			$bindVars = $bind;
 	} 		
-
+	function exist_child_category($parentId, $name) {
+		$query = 'select `categId` from `tiki_categories` where `parentId`=? and `name`=?';
+		return ($this->getOne($query, array((int)$parentId, $name)));
+	}
 }
 
 global $dbTiki;
