@@ -3,11 +3,20 @@
 # Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 # All Rights Reserved. See copyright.txt for details and a complete list of authors.
 # Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
+
+// I call index.php because tiki may not be setup when people attempt to call this.
+if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== FALSE) {
+	header ("location: index.php");
+	die;
+}
+
+
+
 error_reporting (E_ALL);
 
 require_once ('irclib.php');
 
-echo '$Id: split_logs.php,v 1.3.4.2 2007/03/02 12:18:28 luciash Exp $', "\n";
+echo '$Id: split_logs.php,v 1.3.4.3 2008/02/21 21:29:29 marclaporte Exp $', "\n";
 
 if ($argc < 2) {
 	echo "
