@@ -1,5 +1,5 @@
 <?php
-// $Id: notificationemaillib.php,v 1.6.2.23 2007/07/05 22:05:38 sylvieg Exp $
+// $Id: notificationemaillib.php,v 1.6.2.24 2008/02/22 06:54:06 marclaporte Exp $
 /** \brief send the email notifications dealing with the forum changes to
   * \brief outbound address + admin notification addresses / forum admin email + watching users addresses
   * \param $event = 'forum_post_topic' or 'forum_post_thread'
@@ -9,6 +9,12 @@
   * \param $topicName name of the parent topic
   */
 
+//this script may only be included - so its better to die if called directly.
+if (strpos($_SERVER["SCRIPT_NAME"],basename(__FILE__)) !== false) {
+  header("location: index.php");
+  exit;
+}
+
 function sendForumEmailNotification($event, $object, $forum_info, $title, $data, $author, $topicName, $messageId='', $inReplyTo='', $threadId, $parentId='' ) {
 	global $tikilib, $feature_user_watches, $smarty, $userlib, $sender_email;
 
