@@ -1699,7 +1699,7 @@ function get_included_groups($group) {
 			$cachelib->invalidate('userslist');
     }
 
-    function add_user($user, $pass, $email, $realname, $provpass = '', $valid=NULL) {
+    function add_user($user, $pass, $email, $provpass = '', $valid=NULL, $realName='') {
 	global $pass_due, $tikilib, $cachelib, $patterns;
 	global $feature_clear_passwords;
 	// Generate a unique hash; this is also done below in set_user_fields()
@@ -1743,8 +1743,10 @@ function get_included_groups($group) {
 
 	    $this->assign_user_to_group($user, $user);
 	}
+	if (!empty($realName))
+		$this->set_user_preference($user, 'realName', $realName);
 
-			$cachelib->invalidate('userslist');
+	$cachelib->invalidate('userslist');
 	return true;
     }
 
@@ -1803,7 +1805,8 @@ function get_included_groups($group) {
     }
 
     function get_user_name($username) {
-        return $this->getOne("select `value` from `tiki_user_preferences` where `user`='$username' and `prefName`='realName'");
+		$query = "select `value` from `tiki_user_preferences` where `user`=? and `prefName`=?";
+        return $this->getOne($query, array($username, 'realName'));
     }
 
     /**
@@ -1839,7 +1842,7 @@ function get_included_groups($group) {
   }
 
   function get_user_by_cookie($hash) {
-	list($check,$expire,$userCookie) = explode('.',$hash);
+	list($check,$expire,$userCookie) = explode('.',$hash, 3);
     if ($check == md5($_SERVER['REMOTE_ADDR'].$_SERVER['HTTP_USER_AGENT'])) {
       $query = 'select `user` from `tiki_user_preferences` where `prefName`=? and `value`=? and `user`=?';
       $user = $this->getOne($query, array('cookie',"$check.$expire", $userCookie));
