@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-browse_image.php,v 1.24.2.37 2007/03/02 12:23:27 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-browse_image.php,v 1.24.2.38 2008/01/20 16:58:03 lphuberdeau Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -142,7 +142,7 @@ if ($offset) {
 	$smarty->assign('previmg', '');
 }
 
-if (count($listImgId) > $offset + 1) {
+if ( isset( $listImgId[$offset+1] ) ) {
 	$smarty->assign('nextimg', $listImgId[$offset+1]);
 } else {
 	$smarty->assign('nextimg', '');
