@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-download_userfile.php,v 1.6.2.3 2007/03/02 12:23:21 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-download_userfile.php,v 1.6.2.4 2008/02/21 19:52:40 lphuberdeau Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -9,6 +9,13 @@
 // Initialization
 require_once ('tiki-setup.php');
 
+if ($feature_userfiles != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_userfiles");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 include_once ('lib/userfiles/userfileslib.php');
 
 if (!isset($_REQUEST["fileId"])) {
