@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-g-admin_activities.php,v 1.10.2.8 2007/03/02 12:23:16 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-g-admin_activities.php,v 1.10.2.9 2007/11/28 23:36:54 kerrnel22 Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -177,10 +177,14 @@ if (isset($_REQUEST['save_act'])) {
 	$newaid = $activityManager->replace_activity($_REQUEST['pid'], $_REQUEST['activityId'], $vars);
 	$rid = 0;
 
-	if (isset($_REQUEST['userole']) && $_REQUEST['userole'])
+	// If a role is selected from the drop-down list, then use it,
+	// otherwise if the dropdown is "add new" then use the data in
+	// the text input field.  If a user is selected from the drop-down
+	// AND a value is in the input field, then the drop-down will
+	// override the input field.
+	if ($_REQUEST['userole'] != 'add new') {
 		$rid = $_REQUEST['userole'];
-
-	if (!empty($_REQUEST['rolename'])) {
+	} else if (!empty($_REQUEST['rolename'])) {
 		$vars = array(
 			'name' => $_REQUEST['rolename'],
 			'description' => ''
