@@ -1,5 +1,5 @@
 <?php
-// $Header: /cvsroot/tikiwiki/tiki/tiki-image_galleries_rss.php,v 1.23.2.7 2007/03/02 12:23:24 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-image_galleries_rss.php,v 1.23.2.8 2008/02/22 03:56:25 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -10,6 +10,13 @@ require_once ('lib/tikilib.php');
 require_once ('lib/imagegals/imagegallib.php');
 require_once ('lib/rss/rsslib.php');
 
+if ($feature_galleries != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_galleries");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
 if ($rss_image_galleries != 'y') {
         $errmsg=tra("rss feed disabled");
         require_once ('tiki-rss_error.php');
@@ -27,7 +34,7 @@ $output = $rsslib->get_from_cache($uniqueid);
 if ($output["data"]=="EMPTY") {
 	$title = (!empty($title_rss_image_galleries)) ? $title_rss_image_galleries : tra("Tiki RSS feed for image galleries");
 	$desc = (!empty($desc_rss_image_galleries)) ? $desc_rss_image_galleries : tra("Last images uploaded to the image galleries.");
-	
+
 	$now = date("U");
 	$id = "imageId";
 	$titleId = "name";
@@ -35,12 +42,12 @@ if ($output["data"]=="EMPTY") {
 	$dateId = "created";
 	$authorId = "user";
 	$readrepl = "tiki-browse_image.php?imageId=%s";
-	
+
 	$tmp = $tikilib->get_preference('title_rss_'.$feed, '');
 	if ($tmp<>'') $title = $tmp;
 	$tmp = $tikilib->get_preference('desc_rss_'.$feed, '');
 	if ($desc<>'') $desc = $tmp;
-	
+
 	$changes = $imagegallib->list_images(0,$max_rss_image_galleries,$dateId.'_desc', '');
 	$output = $rsslib->generate_feed($feed, $uniqueid, '', $changes, $readrepl, '', $id, $title, $titleId, $desc, $descId, $dateId, $authorId);
 }
