@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-imexport_languages.php,v 1.15.2.3 2007/03/02 12:23:17 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-imexport_languages.php,v 1.15.2.4 2007/10/22 23:18:57 mose Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -42,7 +42,7 @@ $smarty->assign_by_ref('languages_files', $languages_files);
 
 // Save Variables
 if (isset($_REQUEST["imp_language"])) {
-	$imp_language = $_REQUEST["imp_language"];
+	$imp_language = preg_replace('/\.\./','',$_REQUEST['imp_language']);
 
 	$smarty->assign('imp_language', $imp_language);
 }
