@@ -40,6 +40,11 @@ if ($tiki_p_live_support_admin == 'y') {
 		$lsadminlib->add_operator($_REQUEST['user']);
 	}
 
+        if (isset($_REQUEST['offline'])) {
+                check_ticket('ls-offline');
+                $lslib->set_operator_status($_REQUEST['offline'],'offline');
+        }
+
 	if (isset($_REQUEST['removeuser'])) {
 		$area = 'dellsuser';
 		if ($feature_ticketlib2 != 'y' or (isset($_POST['daconfirm']) and isset($_SESSION["ticket_$area"]))) {
