@@ -2,7 +2,7 @@
 
 // $Header$
 
-// Copyright (c) 2002-2005, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
+// Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
@@ -34,6 +34,6 @@ if ($user) {
 
 $smarty->assign('modules', $lsadminlib->get_modules());
 // Display the template
-$smarty->display("tiki-live_support_message.tpl");
+$smarty->display("tiki-live_support_client.tpl");
 
 ?>
