@@ -1,6 +1,6 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/tiki-pdf.php,v 1.8.2.5 2007/03/02 12:23:15 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/tiki-pdf.php,v 1.8.2.6 2008/02/21 20:25:17 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
@@ -9,6 +9,15 @@
 // Initialization
 require_once ('tiki-setup.php');
 
+
+if ($feature_wiki_pdf != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_wiki_pdf");
+
+	$smarty->display("error.tpl");
+	die;
+}
+
+
 include_once ('lib/structures/structlib.php');
 include_once ('lib/wiki/wikilib.php');
 
@@ -79,7 +88,7 @@ if (empty($info["user"])) {
 //$smarty->assign_by_ref('lastUser',$info["user"]);
 
 // Parse the Data into PDF format (:TODO:)
-// 
+//
 include_once ("lib/pdflib/class.ezpdf.php");
 $pdf = &new Cezpdf();
 $pdf->selectFont('lib/fonts/Helvetica');
