@@ -129,11 +129,11 @@ if(isset($_REQUEST['register']) && !empty($_REQUEST['name']) && isset($_REQUEST[
 		if($validateUsers == 'y' || (isset($validateRegistration) && $validateRegistration == 'y')) {
 			$apass = addslashes(md5($tikilib->genPass()));
 			$userlib->send_validation_email($_REQUEST['name'], $apass, $_REQUEST['email']);
-			$userlib->add_user($_REQUEST["name"], $apass, $_REQUEST["email"], $_REQUEST["pass"],'n');
+			$userlib->add_user($_REQUEST["name"], $apass, $_REQUEST["email"], $_REQUEST["pass"], '', 'n');
 			$logslib->add_log('register','created account '.$_REQUEST["name"]);
 			$smarty->assign('showmsg','y');
 		} else {
-			$userlib->add_user($_REQUEST["name"],$_REQUEST["pass"],$_REQUEST["email"],'');
+			$userlib->add_user($_REQUEST["name"],$_REQUEST["pass"],$_REQUEST["email"],'','');
 			$logslib->add_log('register','created account '.$_REQUEST["name"]);
 			$smarty->assign('msg',$smarty->fetch('mail/user_welcome_msg.tpl'));
 			$smarty->assign('showmsg','y');
