@@ -1,21 +1,28 @@
 <?php
 
-// $Header: /cvsroot/tikiwiki/tiki/topic_image.php,v 1.10.2.7 2007/03/02 12:23:13 luciash Exp $
+// $Header: /cvsroot/tikiwiki/tiki/topic_image.php,v 1.10.2.9 2008/02/22 01:45:19 marclaporte Exp $
 
 // Copyright (c) 2002-2007, Luis Argerich, Garland Foster, Eduardo Polidor, et. al.
 // All Rights Reserved. See copyright.txt for details and a complete list of authors.
 // Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
 
-# $Header: /cvsroot/tikiwiki/tiki/topic_image.php,v 1.10.2.7 2007/03/02 12:23:13 luciash Exp $
+include_once ('tiki-setup.php');
 
-// application to display an image from the database with 
+
+if ($feature_articles != 'y') {
+	$smarty->assign('msg', tra("This feature is disabled").": feature_articles");
+	$smarty->display("error.tpl");
+	die;
+}
+
+
+// application to display an image from the database with
 // option to resize the image dynamically creating a thumbnail on the fly.
 if (!isset($_REQUEST["id"])) {
 	die;
 }
 
-include_once ('lib/init/initlib.php');
-include_once ('tiki-setup_base.php');
+
 
 $topiccachefile = "temp";
 if ($tikidomain) { $topiccachefile.= "/$tikidomain"; }
